@@ -1,9 +1,167 @@
+*> \brief \b CSPTRF
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*> \htmlonly
+*> Download CSPTRF + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/csptrf.f">
+*> [TGZ]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/csptrf.f">
+*> [ZIP]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/csptrf.f">
+*> [TXT]</a>
+*> \endhtmlonly
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE CSPTRF( UPLO, N, AP, IPIV, INFO )
+*
+*       .. Scalar Arguments ..
+*       CHARACTER          UPLO
+*       INTEGER            INFO, N
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            IPIV( * )
+*       COMPLEX            AP( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> CSPTRF computes the factorization of a complex symmetric matrix A
+*> stored in packed format using the Bunch-Kaufman diagonal pivoting
+*> method:
+*>
+*>    A = U*D*U**T  or  A = L*D*L**T
+*>
+*> where U (or L) is a product of permutation and unit upper (lower)
+*> triangular matrices, and D is symmetric and block diagonal with
+*> 1-by-1 and 2-by-2 diagonal blocks.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] UPLO
+*> \verbatim
+*>          UPLO is CHARACTER*1
+*>          = 'U':  Upper triangle of A is stored;
+*>          = 'L':  Lower triangle of A is stored.
+*> \endverbatim
+*>
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>          The order of the matrix A.  N >= 0.
+*> \endverbatim
+*>
+*> \param[in,out] AP
+*> \verbatim
+*>          AP is COMPLEX array, dimension (N*(N+1)/2)
+*>          On entry, the upper or lower triangle of the symmetric matrix
+*>          A, packed columnwise in a linear array.  The j-th column of A
+*>          is stored in the array AP as follows:
+*>          if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j;
+*>          if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n.
+*>
+*>          On exit, the block diagonal matrix D and the multipliers used
+*>          to obtain the factor U or L, stored as a packed triangular
+*>          matrix overwriting A (see below for further details).
+*> \endverbatim
+*>
+*> \param[out] IPIV
+*> \verbatim
+*>          IPIV is INTEGER array, dimension (N)
+*>          Details of the interchanges and the block structure of D.
+*>          If IPIV(k) > 0, then rows and columns k and IPIV(k) were
+*>          interchanged and D(k,k) is a 1-by-1 diagonal block.
+*>          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and
+*>          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)
+*>          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =
+*>          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were
+*>          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>          = 0: successful exit
+*>          < 0: if INFO = -i, the i-th argument had an illegal value
+*>          > 0: if INFO = i, D(i,i) is exactly zero.  The factorization
+*>               has been completed, but the block diagonal matrix D is
+*>               exactly singular, and division by zero will occur if it
+*>               is used to solve a system of equations.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup complexOTHERcomputational
+*
+*> \par Further Details:
+*  =====================
+*>
+*> \verbatim
+*>
+*>  5-96 - Based on modifications by J. Lewis, Boeing Computer Services
+*>         Company
+*>
+*>  If UPLO = 'U', then A = U*D*U**T, where
+*>     U = P(n)*U(n)* ... *P(k)U(k)* ...,
+*>  i.e., U is a product of terms P(k)*U(k), where k decreases from n to
+*>  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
+*>  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
+*>  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such
+*>  that if the diagonal block D(k) is of order s (s = 1 or 2), then
+*>
+*>             (   I    v    0   )   k-s
+*>     U(k) =  (   0    I    0   )   s
+*>             (   0    0    I   )   n-k
+*>                k-s   s   n-k
+*>
+*>  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).
+*>  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),
+*>  and A(k,k), and v overwrites A(1:k-2,k-1:k).
+*>
+*>  If UPLO = 'L', then A = L*D*L**T, where
+*>     L = P(1)*L(1)* ... *P(k)*L(k)* ...,
+*>  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to
+*>  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
+*>  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
+*>  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such
+*>  that if the diagonal block D(k) is of order s (s = 1 or 2), then
+*>
+*>             (   I    0     0   )  k-1
+*>     L(k) =  (   0    I     0   )  s
+*>             (   0    v     I   )  n-k-s+1
+*>                k-1   s  n-k-s+1
+*>
+*>  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).
+*>  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),
+*>  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).
+*> \endverbatim
+*>
+*  =====================================================================
       SUBROUTINE CSPTRF( UPLO, N, AP, IPIV, INFO )
 *
-*  -- LAPACK routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     March 31, 1993 
+*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -14,95 +172,6 @@
       COMPLEX            AP( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  CSPTRF computes the factorization of a complex symmetric matrix A
-*  stored in packed format using the Bunch-Kaufman diagonal pivoting
-*  method:
-*
-*     A = U*D*U**T  or  A = L*D*L**T
-*
-*  where U (or L) is a product of permutation and unit upper (lower)
-*  triangular matrices, and D is symmetric and block diagonal with
-*  1-by-1 and 2-by-2 diagonal blocks.
-*
-*  Arguments
-*  =========
-*
-*  UPLO    (input) CHARACTER*1
-*          = 'U':  Upper triangle of A is stored;
-*          = 'L':  Lower triangle of A is stored.
-*
-*  N       (input) INTEGER
-*          The order of the matrix A.  N >= 0.
-*
-*  AP      (input/output) COMPLEX array, dimension (N*(N+1)/2)
-*          On entry, the upper or lower triangle of the symmetric matrix
-*          A, packed columnwise in a linear array.  The j-th column of A
-*          is stored in the array AP as follows:
-*          if UPLO = 'U', AP(i + (j-1)*j/2) = A(i,j) for 1<=i<=j;
-*          if UPLO = 'L', AP(i + (j-1)*(2n-j)/2) = A(i,j) for j<=i<=n.
-*
-*          On exit, the block diagonal matrix D and the multipliers used
-*          to obtain the factor U or L, stored as a packed triangular
-*          matrix overwriting A (see below for further details).
-*
-*  IPIV    (output) INTEGER array, dimension (N)
-*          Details of the interchanges and the block structure of D.
-*          If IPIV(k) > 0, then rows and columns k and IPIV(k) were
-*          interchanged and D(k,k) is a 1-by-1 diagonal block.
-*          If UPLO = 'U' and IPIV(k) = IPIV(k-1) < 0, then rows and
-*          columns k-1 and -IPIV(k) were interchanged and D(k-1:k,k-1:k)
-*          is a 2-by-2 diagonal block.  If UPLO = 'L' and IPIV(k) =
-*          IPIV(k+1) < 0, then rows and columns k+1 and -IPIV(k) were
-*          interchanged and D(k:k+1,k:k+1) is a 2-by-2 diagonal block.
-*
-*  INFO    (output) INTEGER
-*          = 0: successful exit
-*          < 0: if INFO = -i, the i-th argument had an illegal value
-*          > 0: if INFO = i, D(i,i) is exactly zero.  The factorization
-*               has been completed, but the block diagonal matrix D is
-*               exactly singular, and division by zero will occur if it
-*               is used to solve a system of equations.
-*
-*  Further Details
-*  ===============
-*
-*  If UPLO = 'U', then A = U*D*U', where
-*     U = P(n)*U(n)* ... *P(k)U(k)* ...,
-*  i.e., U is a product of terms P(k)*U(k), where k decreases from n to
-*  1 in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
-*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
-*  defined by IPIV(k), and U(k) is a unit upper triangular matrix, such
-*  that if the diagonal block D(k) is of order s (s = 1 or 2), then
-*
-*             (   I    v    0   )   k-s
-*     U(k) =  (   0    I    0   )   s
-*             (   0    0    I   )   n-k
-*                k-s   s   n-k
-*
-*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(1:k-1,k).
-*  If s = 2, the upper triangle of D(k) overwrites A(k-1,k-1), A(k-1,k),
-*  and A(k,k), and v overwrites A(1:k-2,k-1:k).
-*
-*  If UPLO = 'L', then A = L*D*L', where
-*     L = P(1)*L(1)* ... *P(k)*L(k)* ...,
-*  i.e., L is a product of terms P(k)*L(k), where k increases from 1 to
-*  n in steps of 1 or 2, and D is a block diagonal matrix with 1-by-1
-*  and 2-by-2 diagonal blocks D(k).  P(k) is a permutation matrix as
-*  defined by IPIV(k), and L(k) is a unit lower triangular matrix, such
-*  that if the diagonal block D(k) is of order s (s = 1 or 2), then
-*
-*             (   I    0     0   )  k-1
-*     L(k) =  (   0    I     0   )  s
-*             (   0    v     I   )  n-k-s+1
-*                k-1   s  n-k-s+1
-*
-*  If s = 1, D(k) overwrites A(k,k), and v overwrites A(k+1:n,k).
-*  If s = 2, the lower triangle of D(k) overwrites A(k,k), A(k+1,k),
-*  and A(k+1,k+1), and v overwrites A(k+2:n,k:k+1).
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -115,11 +184,10 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            UPPER
-      INTEGER            IMAX, J, JC, JMAX, K, KC, KK, KNC, KP, KPC,
+      INTEGER            I, IMAX, J, JMAX, K, KC, KK, KNC, KP, KPC,
      $                   KSTEP, KX, NPP
       REAL               ABSAKK, ALPHA, COLMAX, ROWMAX
-      COMPLEX            C, D11, D12, D21, D22, R1, R2, S, T, T1, T2, Z,
-     $                   ZDUM
+      COMPLEX            D11, D12, D21, D22, R1, T, WK, WKM1, WKP1, ZDUM
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -127,8 +195,7 @@
       EXTERNAL           LSAME, ICAMAX
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CAXPY, CLACRT, CLAESY, CSCAL, CSPR, CSWAP,
-     $                   XERBLA
+      EXTERNAL           CSCAL, CSPR, CSWAP, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, AIMAG, MAX, REAL, SQRT
@@ -161,7 +228,7 @@
 *
       IF( UPPER ) THEN
 *
-*        Factorize A as U*D*U' using the upper triangle of A
+*        Factorize A as U*D*U**T using the upper triangle of A
 *
 *        K is the main loop index, decreasing from N to 1 in steps of
 *        1 or 2
@@ -174,7 +241,7 @@
 *        If K < 1, exit from loop
 *
          IF( K.LT.1 )
-     $      GO TO 90
+     $      GO TO 110
          KSTEP = 1
 *
 *        Determine rows and columns to be interchanged and whether
@@ -206,9 +273,6 @@
 *
                KP = K
             ELSE
-*
-*              JMAX is the column-index of the largest off-diagonal
-*              element in row IMAX, and ROWMAX is its absolute value
 *
                ROWMAX = ZERO
                JMAX = IMAX
@@ -285,7 +349,7 @@
 *
 *              Perform a rank-1 update of A(1:k-1,1:k-1) as
 *
-*              A := A - U(k)*D(k)*U(k)' = A - W(k)*1/D(k)*W(k)'
+*              A := A - U(k)*D(k)*U(k)**T = A - W(k)*1/D(k)*W(k)**T
 *
                R1 = CONE / AP( KC+K-1 )
                CALL CSPR( UPLO, K-1, -R1, AP( KC ), 1, AP )
@@ -304,62 +368,31 @@
 *
 *              Perform a rank-2 update of A(1:k-2,1:k-2) as
 *
-*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )'
-*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )'
+*              A := A - ( U(k-1) U(k) )*D(k)*( U(k-1) U(k) )**T
+*                 = A - ( W(k-1) W(k) )*inv(D(k))*( W(k-1) W(k) )**T
 *
-*              Convert this to two rank-1 updates by using the eigen-
-*              decomposition of D(k)
+               IF( K.GT.2 ) THEN
 *
-               CALL CLAESY( AP( KC-1 ), AP( KC+K-2 ), AP( KC+K-1 ), R1,
-     $                      R2, Z, C, S )
+                  D12 = AP( K-1+( K-1 )*K / 2 )
+                  D22 = AP( K-1+( K-2 )*( K-1 ) / 2 ) / D12
+                  D11 = AP( K+( K-1 )*K / 2 ) / D12
+                  T = CONE / ( D11*D22-CONE )
+                  D12 = T / D12
 *
-               IF( CABS1( Z ).NE.ZERO ) THEN
+                  DO 50 J = K - 2, 1, -1
+                     WKM1 = D12*( D11*AP( J+( K-2 )*( K-1 ) / 2 )-
+     $                      AP( J+( K-1 )*K / 2 ) )
+                     WK = D12*( D22*AP( J+( K-1 )*K / 2 )-
+     $                    AP( J+( K-2 )*( K-1 ) / 2 ) )
+                     DO 40 I = J, 1, -1
+                        AP( I+( J-1 )*J / 2 ) = AP( I+( J-1 )*J / 2 ) -
+     $                     AP( I+( K-1 )*K / 2 )*WK -
+     $                     AP( I+( K-2 )*( K-1 ) / 2 )*WKM1
+   40                CONTINUE
+                     AP( J+( K-1 )*K / 2 ) = WK
+                     AP( J+( K-2 )*( K-1 ) / 2 ) = WKM1
+   50             CONTINUE
 *
-*                 Apply two rank-1 updates to A(1:k-2,1:k-2) using the
-*                 eigendecomposition of D(k).
-*
-                  R1 = CONE / R1
-                  R2 = CONE / R2
-                  CALL CLACRT( K-2, AP( KNC ), 1, AP( KC ), 1, C, S )
-                  CALL CSPR( UPLO, K-2, -R1, AP( KNC ), 1, AP )
-                  CALL CSPR( UPLO, K-2, -R2, AP( KC ), 1, AP )
-*
-*                 Store the multipliers in columns K and K-1
-*
-                  CALL CSCAL( K-2, R1, AP( KNC ), 1 )
-                  CALL CSCAL( K-2, R2, AP( KC ), 1 )
-                  CALL CLACRT( K-2, AP( KNC ), 1, AP( KC ), 1, C, -S )
-               ELSE
-*
-*                 Apply a rank-2 update to A(1:k-2,1:k-2) using the
-*                 explicit inverse of D(K) = [a b; b c], computed as
-*                                 (1/b)      (  c/b    -1  )
-*                 inv(D(k)) = -------------- (             )
-*                             1 - (a/b)(c/b) (  -1     a/b )
-*
-                  D12 = CONE / AP( KC+K-2 )
-                  D11 = AP( KC+K-1 )*D12
-                  D22 = AP( KC-1 )*D12
-                  Z = -D12 / ( CONE-D11*D22 )
-                  JC = KNC - K + 2
-                  DO 40 J = K - 2, 1, -1
-*
-*                    Compute inv(D(k)) * A(j,k-1:k)'
-*
-                     T1 = Z*( D11*AP( KNC+J-1 )-AP( KC+J-1 ) )
-                     T2 = Z*( D22*AP( KC+J-1 )-AP( KNC+J-1 ) )
-*
-*                    Update column j of A
-*
-                     CALL CAXPY( J, -T1, AP( KNC ), 1, AP( JC ), 1 )
-                     CALL CAXPY( J, -T2, AP( KC ), 1, AP( JC ), 1 )
-*
-*                    Store the multipliers in columns K-1 and K
-*
-                     AP( KNC+J-1 ) = T1
-                     AP( KC+J-1 ) = T2
-                     JC = JC - J + 1
-   40             CONTINUE
                END IF
             END IF
          END IF
@@ -381,7 +414,7 @@
 *
       ELSE
 *
-*        Factorize A as L*D*L' using the lower triangle of A
+*        Factorize A as L*D*L**T using the lower triangle of A
 *
 *        K is the main loop index, increasing from 1 to N in steps of
 *        1 or 2
@@ -389,13 +422,13 @@
          K = 1
          KC = 1
          NPP = N*( N+1 ) / 2
-   50    CONTINUE
+   60    CONTINUE
          KNC = KC
 *
 *        If K > N, exit from loop
 *
          IF( K.GT.N )
-     $      GO TO 90
+     $      GO TO 110
          KSTEP = 1
 *
 *        Determine rows and columns to be interchanged and whether
@@ -433,13 +466,13 @@
 *
                ROWMAX = ZERO
                KX = KC + IMAX - K
-               DO 60 J = K, IMAX - 1
+               DO 70 J = K, IMAX - 1
                   IF( CABS1( AP( KX ) ).GT.ROWMAX ) THEN
                      ROWMAX = CABS1( AP( KX ) )
                      JMAX = J
                   END IF
                   KX = KX + N - J
-   60          CONTINUE
+   70          CONTINUE
                KPC = NPP - ( N-IMAX+1 )*( N-IMAX+2 ) / 2 + 1
                IF( IMAX.LT.N ) THEN
                   JMAX = IMAX + ICAMAX( N-IMAX, AP( KPC+1 ), 1 )
@@ -479,12 +512,12 @@
      $            CALL CSWAP( N-KP, AP( KNC+KP-KK+1 ), 1, AP( KPC+1 ),
      $                        1 )
                KX = KNC + KP - KK
-               DO 70 J = KK + 1, KP - 1
+               DO 80 J = KK + 1, KP - 1
                   KX = KX + N - J + 1
                   T = AP( KNC+J-KK )
                   AP( KNC+J-KK ) = AP( KX )
                   AP( KX ) = T
-   70          CONTINUE
+   80          CONTINUE
                T = AP( KNC )
                AP( KNC ) = AP( KPC )
                AP( KPC ) = T
@@ -509,7 +542,7 @@
 *
 *                 Perform a rank-1 update of A(k+1:n,k+1:n) as
 *
-*                 A := A - L(k)*D(k)*L(k)' = A - W(k)*(1/D(k))*W(k)'
+*                 A := A - L(k)*D(k)*L(k)**T = A - W(k)*(1/D(k))*W(k)**T
 *
                   R1 = CONE / AP( KC )
                   CALL CSPR( UPLO, N-K, -R1, AP( KC+1 ), 1,
@@ -532,69 +565,31 @@
 *
 *                 Perform a rank-2 update of A(k+2:n,k+2:n) as
 *
-*                 A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )'
-*                    = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )'
+*                 A := A - ( L(k) L(k+1) )*D(k)*( L(k) L(k+1) )**T
+*                    = A - ( W(k) W(k+1) )*inv(D(k))*( W(k) W(k+1) )**T
 *
-*                 Convert this to two rank-1 updates by using the eigen-
-*                 decomposition of D(k)
+*                 where L(k) and L(k+1) are the k-th and (k+1)-th
+*                 columns of L
 *
-                  CALL CLAESY( AP( KC ), AP( KC+1 ), AP( KNC ), R1, R2,
-     $                         Z, C, S )
+                  D21 = AP( K+1+( K-1 )*( 2*N-K ) / 2 )
+                  D11 = AP( K+1+K*( 2*N-K-1 ) / 2 ) / D21
+                  D22 = AP( K+( K-1 )*( 2*N-K ) / 2 ) / D21
+                  T = CONE / ( D11*D22-CONE )
+                  D21 = T / D21
 *
-                  IF( CABS1( Z ).NE.ZERO ) THEN
-*
-*                    Apply two rank-1 updates to A(k+2:n,k+2:n) using
-*                    the eigendecomposition of D(k)
-*
-                     R1 = CONE / R1
-                     R2 = CONE / R2
-                     CALL CLACRT( N-K-1, AP( KC+2 ), 1, AP( KNC+1 ), 1,
-     $                            C, S )
-                     CALL CSPR( UPLO, N-K-1, -R1, AP( KC+2 ), 1,
-     $                          AP( KNC+N-K ) )
-                     CALL CSPR( UPLO, N-K-1, -R2, AP( KNC+1 ), 1,
-     $                          AP( KNC+N-K ) )
-*
-*                    Store the multipliers in columns K and K+1
-*
-                     CALL CSCAL( N-K-1, R1, AP( KC+2 ), 1 )
-                     CALL CSCAL( N-K-1, R2, AP( KNC+1 ), 1 )
-                     CALL CLACRT( N-K-1, AP( KC+2 ), 1, AP( KNC+1 ), 1,
-     $                            C, -S )
-                  ELSE
-*
-*                    Apply a rank-2 update to A(k+2:n,k+2:n) using the
-*                    explicit inverse of D(K) = [a b; b c], computed as
-*                                    (1/b)      (  c/b    -1  )
-*                    inv(D(k)) = -------------- (             )
-*                                1 - (a/b)(c/b) (  -1     a/b )
-*
-                     D21 = CONE / AP( KC+1 )
-                     D11 = AP( KNC )*D21
-                     D22 = AP( KC )*D21
-                     Z = -D21 / ( CONE-D11*D22 )
-                     JC = KNC + N - K
-                     DO 80 J = K + 2, N
-*
-*                       Compute inv(D(k)) * A(j,k:k+1)'
-*
-                        T1 = Z*( D11*AP( KC+J-K )-AP( KNC+J-( K+1 ) ) )
-                        T2 = Z*( D22*AP( KNC+J-( K+1 ) )-AP( KC+J-K ) )
-*
-*                       Update column j of A
-*
-                        CALL CAXPY( N-J+1, -T1, AP( KC+J-K ), 1,
-     $                              AP( JC ), 1 )
-                        CALL CAXPY( N-J+1, -T2, AP( KNC+J-( K+1 ) ), 1,
-     $                              AP( JC ), 1 )
-*
-*                       Store the multipliers in columns K and K+1
-*
-                        AP( KC+J-K ) = T1
-                        AP( KNC+J-( K+1 ) ) = T2
-                        JC = JC + N - J + 1
-   80                CONTINUE
-                  END IF
+                  DO 100 J = K + 2, N
+                     WK = D21*( D11*AP( J+( K-1 )*( 2*N-K ) / 2 )-
+     $                    AP( J+K*( 2*N-K-1 ) / 2 ) )
+                     WKP1 = D21*( D22*AP( J+K*( 2*N-K-1 ) / 2 )-
+     $                      AP( J+( K-1 )*( 2*N-K ) / 2 ) )
+                     DO 90 I = J, N
+                        AP( I+( J-1 )*( 2*N-J ) / 2 ) = AP( I+( J-1 )*
+     $                     ( 2*N-J ) / 2 ) - AP( I+( K-1 )*( 2*N-K ) /
+     $                     2 )*WK - AP( I+K*( 2*N-K-1 ) / 2 )*WKP1
+   90                CONTINUE
+                     AP( J+( K-1 )*( 2*N-K ) / 2 ) = WK
+                     AP( J+K*( 2*N-K-1 ) / 2 ) = WKP1
+  100             CONTINUE
                END IF
             END IF
          END IF
@@ -612,11 +607,11 @@
 *
          K = K + KSTEP
          KC = KNC + N - K + 2
-         GO TO 50
+         GO TO 60
 *
       END IF
 *
-   90 CONTINUE
+  110 CONTINUE
       RETURN
 *
 *     End of CSPTRF
