@@ -1,10 +1,168 @@
+*> \brief \b SSBGST
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*> \htmlonly
+*> Download SSBGST + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/ssbgst.f">
+*> [TGZ]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/ssbgst.f">
+*> [ZIP]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/ssbgst.f">
+*> [TXT]</a>
+*> \endhtmlonly
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SSBGST( VECT, UPLO, N, KA, KB, AB, LDAB, BB, LDBB, X,
+*                          LDX, WORK, INFO )
+*
+*       .. Scalar Arguments ..
+*       CHARACTER          UPLO, VECT
+*       INTEGER            INFO, KA, KB, LDAB, LDBB, LDX, N
+*       ..
+*       .. Array Arguments ..
+*       REAL               AB( LDAB, * ), BB( LDBB, * ), WORK( * ),
+*      $                   X( LDX, * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SSBGST reduces a real symmetric-definite banded generalized
+*> eigenproblem  A*x = lambda*B*x  to standard form  C*y = lambda*y,
+*> such that C has the same bandwidth as A.
+*>
+*> B must have been previously factorized as S**T*S by SPBSTF, using a
+*> split Cholesky factorization. A is overwritten by C = X**T*A*X, where
+*> X = S**(-1)*Q and Q is an orthogonal matrix chosen to preserve the
+*> bandwidth of A.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] VECT
+*> \verbatim
+*>          VECT is CHARACTER*1
+*>          = 'N':  do not form the transformation matrix X;
+*>          = 'V':  form X.
+*> \endverbatim
+*>
+*> \param[in] UPLO
+*> \verbatim
+*>          UPLO is CHARACTER*1
+*>          = 'U':  Upper triangle of A is stored;
+*>          = 'L':  Lower triangle of A is stored.
+*> \endverbatim
+*>
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>          The order of the matrices A and B.  N >= 0.
+*> \endverbatim
+*>
+*> \param[in] KA
+*> \verbatim
+*>          KA is INTEGER
+*>          The number of superdiagonals of the matrix A if UPLO = 'U',
+*>          or the number of subdiagonals if UPLO = 'L'.  KA >= 0.
+*> \endverbatim
+*>
+*> \param[in] KB
+*> \verbatim
+*>          KB is INTEGER
+*>          The number of superdiagonals of the matrix B if UPLO = 'U',
+*>          or the number of subdiagonals if UPLO = 'L'.  KA >= KB >= 0.
+*> \endverbatim
+*>
+*> \param[in,out] AB
+*> \verbatim
+*>          AB is REAL array, dimension (LDAB,N)
+*>          On entry, the upper or lower triangle of the symmetric band
+*>          matrix A, stored in the first ka+1 rows of the array.  The
+*>          j-th column of A is stored in the j-th column of the array AB
+*>          as follows:
+*>          if UPLO = 'U', AB(ka+1+i-j,j) = A(i,j) for max(1,j-ka)<=i<=j;
+*>          if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+ka).
+*>
+*>          On exit, the transformed matrix X**T*A*X, stored in the same
+*>          format as A.
+*> \endverbatim
+*>
+*> \param[in] LDAB
+*> \verbatim
+*>          LDAB is INTEGER
+*>          The leading dimension of the array AB.  LDAB >= KA+1.
+*> \endverbatim
+*>
+*> \param[in] BB
+*> \verbatim
+*>          BB is REAL array, dimension (LDBB,N)
+*>          The banded factor S from the split Cholesky factorization of
+*>          B, as returned by SPBSTF, stored in the first KB+1 rows of
+*>          the array.
+*> \endverbatim
+*>
+*> \param[in] LDBB
+*> \verbatim
+*>          LDBB is INTEGER
+*>          The leading dimension of the array BB.  LDBB >= KB+1.
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is REAL array, dimension (LDX,N)
+*>          If VECT = 'V', the n-by-n matrix X.
+*>          If VECT = 'N', the array X is not referenced.
+*> \endverbatim
+*>
+*> \param[in] LDX
+*> \verbatim
+*>          LDX is INTEGER
+*>          The leading dimension of the array X.
+*>          LDX >= max(1,N) if VECT = 'V'; LDX >= 1 otherwise.
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is REAL array, dimension (2*N)
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>          = 0:  successful exit
+*>          < 0:  if INFO = -i, the i-th argument had an illegal value.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup realOTHERcomputational
+*
+*  =====================================================================
       SUBROUTINE SSBGST( VECT, UPLO, N, KA, KB, AB, LDAB, BB, LDBB, X,
      $                   LDX, WORK, INFO )
 *
-*  -- LAPACK routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO, VECT
@@ -15,76 +173,6 @@
      $                   X( LDX, * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SSBGST reduces a real symmetric-definite banded generalized
-*  eigenproblem  A*x = lambda*B*x  to standard form  C*y = lambda*y,
-*  such that C has the same bandwidth as A.
-*
-*  B must have been previously factorized as S**T*S by SPBSTF, using a
-*  split Cholesky factorization. A is overwritten by C = X**T*A*X, where
-*  X = S**(-1)*Q and Q is an orthogonal matrix chosen to preserve the
-*  bandwidth of A.
-*
-*  Arguments
-*  =========
-*
-*  VECT    (input) CHARACTER*1
-*          = 'N':  do not form the transformation matrix X;
-*          = 'V':  form X.
-*
-*  UPLO    (input) CHARACTER*1
-*          = 'U':  Upper triangle of A is stored;
-*          = 'L':  Lower triangle of A is stored.
-*
-*  N       (input) INTEGER
-*          The order of the matrices A and B.  N >= 0.
-*
-*  KA      (input) INTEGER
-*          The number of superdiagonals of the matrix A if UPLO = 'U',
-*          or the number of subdiagonals if UPLO = 'L'.  KA >= 0.
-*
-*  KB      (input) INTEGER
-*          The number of superdiagonals of the matrix B if UPLO = 'U',
-*          or the number of subdiagonals if UPLO = 'L'.  KA >= KB >= 0.
-*
-*  AB      (input/output) REAL array, dimension (LDAB,N)
-*          On entry, the upper or lower triangle of the symmetric band
-*          matrix A, stored in the first ka+1 rows of the array.  The
-*          j-th column of A is stored in the j-th column of the array AB
-*          as follows:
-*          if UPLO = 'U', AB(ka+1+i-j,j) = A(i,j) for max(1,j-ka)<=i<=j;
-*          if UPLO = 'L', AB(1+i-j,j)    = A(i,j) for j<=i<=min(n,j+ka).
-*
-*          On exit, the transformed matrix X**T*A*X, stored in the same
-*          format as A.
-*
-*  LDAB    (input) INTEGER
-*          The leading dimension of the array AB.  LDAB >= KA+1.
-*
-*  BB      (input) REAL array, dimension (LDBB,N)
-*          The banded factor S from the split Cholesky factorization of
-*          B, as returned by SPBSTF, stored in the first KB+1 rows of
-*          the array.
-*
-*  LDBB    (input) INTEGER
-*          The leading dimension of the array BB.  LDBB >= KB+1.
-*
-*  X       (output) REAL array, dimension (LDX,N)
-*          If VECT = 'V', the n-by-n matrix X.
-*          If VECT = 'N', the array X is not referenced.
-*
-*  LDX     (input) INTEGER
-*          The leading dimension of the array X.
-*          LDX >= max(1,N) if VECT = 'V'; LDX >= 1 otherwise.
-*
-*  WORK    (workspace) REAL array, dimension (2*N)
-*
-*  INFO    (output) INTEGER
-*          = 0:  successful exit
-*          < 0:  if INFO = -i, the i-th argument had an illegal value.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -125,7 +213,7 @@
          INFO = -3
       ELSE IF( KA.LT.0 ) THEN
          INFO = -4
-      ELSE IF( KB.LT.0 ) THEN
+      ELSE IF( KB.LT.0 .OR. KB.GT.KA ) THEN
          INFO = -5
       ELSE IF( LDAB.LT.KA+1 ) THEN
          INFO = -7
@@ -494,10 +582,12 @@
   220       CONTINUE
   230    CONTINUE
 *
-         DO 240 J = N - 1, I2 + KA, -1
-            WORK( N+J-M ) = WORK( N+J-KA-M )
-            WORK( J-M ) = WORK( J-KA-M )
-  240    CONTINUE
+         IF( KB.GT.1 ) THEN
+            DO 240 J = N - 1, I - KB + 2*KA + 1, -1
+               WORK( N+J-M ) = WORK( N+J-KA-M )
+               WORK( J-M ) = WORK( J-KA-M )
+  240       CONTINUE
+         END IF
 *
       ELSE
 *
@@ -750,10 +840,12 @@
   450       CONTINUE
   460    CONTINUE
 *
-         DO 470 J = N - 1, I2 + KA, -1
-            WORK( N+J-M ) = WORK( N+J-KA-M )
-            WORK( J-M ) = WORK( J-KA-M )
-  470    CONTINUE
+         IF( KB.GT.1 ) THEN
+            DO 470 J = N - 1, I - KB + 2*KA + 1, -1
+               WORK( N+J-M ) = WORK( N+J-KA-M )
+               WORK( J-M ) = WORK( J-KA-M )
+  470       CONTINUE
+         END IF
 *
       END IF
 *
@@ -1063,10 +1155,12 @@
   700       CONTINUE
   710    CONTINUE
 *
-         DO 720 J = 2, I2 - KA
-            WORK( N+J ) = WORK( N+J+KA )
-            WORK( J ) = WORK( J+KA )
-  720    CONTINUE
+         IF( KB.GT.1 ) THEN
+            DO 720 J = 2, MIN( I+KB, M ) - 2*KA - 1
+               WORK( N+J ) = WORK( N+J+KA )
+               WORK( J ) = WORK( J+KA )
+  720       CONTINUE
+         END IF
 *
       ELSE
 *
@@ -1324,10 +1418,12 @@
   930       CONTINUE
   940    CONTINUE
 *
-         DO 950 J = 2, I2 - KA
-            WORK( N+J ) = WORK( N+J+KA )
-            WORK( J ) = WORK( J+KA )
-  950    CONTINUE
+         IF( KB.GT.1 ) THEN
+            DO 950 J = 2, MIN( I+KB, M ) - 2*KA - 1
+               WORK( N+J ) = WORK( N+J+KA )
+               WORK( J ) = WORK( J+KA )
+  950       CONTINUE
+         END IF
 *
       END IF
 *
