@@ -1,70 +1,137 @@
+*> \brief \b ALAHD
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE ALAHD( IOUNIT, PATH )
+*
+*       .. Scalar Arguments ..
+*       CHARACTER*3        PATH
+*       INTEGER            IOUNIT
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> ALAHD prints header information for the different test paths.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] IOUNIT
+*> \verbatim
+*>          IOUNIT is INTEGER
+*>          The unit number to which the header information should be
+*>          printed.
+*> \endverbatim
+*>
+*> \param[in] PATH
+*> \verbatim
+*>          PATH is CHARACTER*3
+*>          The name of the path for which the header information is to
+*>          be printed.  Current paths are
+*>             _GE:  General matrices
+*>             _GB:  General band
+*>             _GT:  General Tridiagonal
+*>             _PO:  Symmetric or Hermitian positive definite
+*>             _PS:  Symmetric or Hermitian positive semi-definite
+*>             _PP:  Symmetric or Hermitian positive definite packed
+*>             _PB:  Symmetric or Hermitian positive definite band
+*>             _PT:  Symmetric or Hermitian positive definite tridiagonal
+*>             _SY:  Symmetric indefinite,
+*>                     with partial (Bunch-Kaufman) pivoting
+*>             _SR:  Symmetric indefinite,
+*>                     with rook (bounded Bunch-Kaufman) pivoting
+*>             _SK:  Symmetric indefinite,
+*>                     with rook (bounded Bunch-Kaufman) pivoting
+*>                     ( new storage format for factors:
+*>                       L and diagonal of D is stored in A,
+*>                       subdiagonal of D is stored in E )
+*>             _SP:  Symmetric indefinite packed,
+*>                     with partial (Bunch-Kaufman) pivoting
+*>             _HA:  (complex) Hermitian ,
+*>                     with Aasen Algorithm
+*>             _HE:  (complex) Hermitian indefinite,
+*>                     with partial (Bunch-Kaufman) pivoting
+*>             _HR:  (complex) Hermitian indefinite,
+*>                     with rook (bounded Bunch-Kaufman) pivoting
+*>             _HK:  (complex) Hermitian indefinite,
+*>                     with rook (bounded Bunch-Kaufman) pivoting
+*>                     ( new storage format for factors:
+*>                       L and diagonal of D is stored in A,
+*>                       subdiagonal of D is stored in E )
+*>             _HP:  (complex) Hermitian indefinite packed,
+*>                     with partial (Bunch-Kaufman) pivoting
+*>             _TR:  Triangular
+*>             _TP:  Triangular packed
+*>             _TB:  Triangular band
+*>             _QR:  QR (general matrices)
+*>             _LQ:  LQ (general matrices)
+*>             _QL:  QL (general matrices)
+*>             _RQ:  RQ (general matrices)
+*>             _QP:  QR with column pivoting
+*>             _TZ:  Trapezoidal
+*>             _LS:  Least Squares driver routines
+*>             _LU:  LU variants
+*>             _CH:  Cholesky variants
+*>             _QS:  QR variants
+*>             _QT:  QRT (general matrices)
+*>             _QX:  QRT (triangular-pentagonal matrices)
+*>          The first character must be one of S, D, C, or Z (C or Z only
+*>          if complex).
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup aux_lin
+*
+*  =====================================================================
       SUBROUTINE ALAHD( IOUNIT, PATH )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     February 29, 1992
+*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            IOUNIT
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  ALAHD prints header information for the different test paths.
-*
-*  Arguments
-*  =========
-*
-*  IOUNIT  (input) INTEGER
-*          The unit number to which the header information should be
-*          printed.
-*
-*  PATH    (input) CHARACTER*3
-*          The name of the path for which the header information is to
-*          be printed.  Current paths are
-*             _GE:  General matrices
-*             _GB:  General band
-*             _GT:  General Tridiagonal
-*             _PO:  Symmetric or Hermitian positive definite
-*             _PP:  Symmetric or Hermitian positive definite packed
-*             _PB:  Symmetric or Hermitian positive definite band
-*             _PT:  Symmetric or Hermitian positive definite tridiagonal
-*             _SY:  Symmetric indefinite
-*             _SP:  Symmetric indefinite packed
-*             _HE:  (complex) Hermitian indefinite
-*             _HP:  (complex) Hermitian indefinite packed
-*             _TR:  Triangular
-*             _TP:  Triangular packed
-*             _TB:  Triangular band
-*             _QR:  QR (general matrices)
-*             _LQ:  LQ (general matrices)
-*             _QL:  QL (general matrices)
-*             _RQ:  RQ (general matrices)
-*             _QP:  QR with column pivoting
-*             _TZ:  Trapezoidal
-*             _LS:  Least Squares driver routines
-*             _LU:  LU variants
-*             _CH:  Cholesky variants
-*             _QS:  QR variants
-*          The first character must be one of S, D, C, or Z (C or Z only
-*          if complex).
-*
 *  =====================================================================
 *
 *     .. Local Scalars ..
       LOGICAL            CORZ, SORD
       CHARACTER          C1, C3
       CHARACTER*2        P2
-      CHARACTER*6        SUBNAM
+      CHARACTER*4        EIGCNM
+      CHARACTER*32       SUBNAM
       CHARACTER*9        SYM
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME, LSAMEN
       EXTERNAL           LSAME, LSAMEN
 *     ..
+*     .. Intrinsic Functions ..
+      INTRINSIC          LEN_TRIM
+*     ..
 *     .. Executable Statements ..
 *
       IF( IOUNIT.LE.0 )
@@ -156,6 +223,28 @@
          WRITE( IOUNIT, FMT = 9955 )8
          WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
 *
+      ELSE IF( LSAMEN( 2, P2, 'PS' ) ) THEN
+*
+*        PS: Positive semi-definite full
+*
+         IF( SORD ) THEN
+            SYM = 'Symmetric'
+         ELSE
+            SYM = 'Hermitian'
+         END IF
+         IF( LSAME( C1, 'S' ) .OR. LSAME( C1, 'C' ) ) THEN
+            EIGCNM = '1E04'
+         ELSE
+            EIGCNM = '1D12'
+         END IF
+         WRITE( IOUNIT, FMT = 9995 )PATH, SYM
+         WRITE( IOUNIT, FMT = '( '' Matrix types:'' )' )
+         WRITE( IOUNIT, FMT = 8973 )EIGCNM, EIGCNM, EIGCNM
+         WRITE( IOUNIT, FMT = '( '' Difference:'' )' )
+         WRITE( IOUNIT, FMT = 8972 )C1
+         WRITE( IOUNIT, FMT = '( '' Test ratio:'' )' )
+         WRITE( IOUNIT, FMT = 8950 )
+         WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
       ELSE IF( LSAMEN( 2, P2, 'PB' ) ) THEN
 *
 *        PB: Positive definite band
@@ -197,10 +286,70 @@
          WRITE( IOUNIT, FMT = 9955 )7
          WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
 *
-      ELSE IF( LSAMEN( 2, P2, 'SY' ) .OR. LSAMEN( 2, P2, 'SP' ) ) THEN
+      ELSE IF( LSAMEN( 2, P2, 'SY' )  ) THEN
 *
-*        SY: Symmetric indefinite full
-*        SP: Symmetric indefinite packed
+*        SY: Symmetric indefinite full,
+*            with partial (Bunch-Kaufman) pivoting algorithm
+*
+         IF( LSAME( C3, 'Y' ) ) THEN
+            WRITE( IOUNIT, FMT = 9992 )PATH, 'Symmetric'
+         ELSE
+            WRITE( IOUNIT, FMT = 9991 )PATH, 'Symmetric'
+         END IF
+         WRITE( IOUNIT, FMT = '( '' Matrix types:'' )' )
+         IF( SORD ) THEN
+            WRITE( IOUNIT, FMT = 9972 )
+         ELSE
+            WRITE( IOUNIT, FMT = 9971 )
+         END IF
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 9953 )1
+         WRITE( IOUNIT, FMT = 9961 )2
+         WRITE( IOUNIT, FMT = 9960 )3
+         WRITE( IOUNIT, FMT = 9960 )4
+         WRITE( IOUNIT, FMT = 9959 )5
+         WRITE( IOUNIT, FMT = 9958 )6
+         WRITE( IOUNIT, FMT = 9956 )7
+         WRITE( IOUNIT, FMT = 9957 )8
+         WRITE( IOUNIT, FMT = 9955 )9
+         WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
+*
+      ELSE IF( LSAMEN( 2, P2, 'SR' ) .OR. LSAMEN( 2, P2, 'SK') ) THEN
+*
+*        SR: Symmetric indefinite full,
+*            with rook (bounded Bunch-Kaufman) pivoting algorithm
+*
+*        SK: Symmetric indefinite full,
+*            with rook (bounded Bunch-Kaufman) pivoting algorithm,
+*            ( new storage format for factors:
+*              L and diagonal of D is stored in A,
+*              subdiagonal of D is stored in E )
+*
+         WRITE( IOUNIT, FMT = 9892 )PATH, 'Symmetric'
+*
+         WRITE( IOUNIT, FMT = '( '' Matrix types:'' )' )
+         IF( SORD ) THEN
+            WRITE( IOUNIT, FMT = 9972 )
+         ELSE
+            WRITE( IOUNIT, FMT = 9971 )
+         END IF
+*
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 9953 )1
+         WRITE( IOUNIT, FMT = 9961 )2
+         WRITE( IOUNIT, FMT = 9927 )3
+         WRITE( IOUNIT, FMT = 9928 )
+         WRITE( IOUNIT, FMT = 9926 )4
+         WRITE( IOUNIT, FMT = 9928 )
+         WRITE( IOUNIT, FMT = 9960 )5
+         WRITE( IOUNIT, FMT = 9959 )6
+         WRITE( IOUNIT, FMT = 9955 )7
+         WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
+*
+      ELSE IF( LSAMEN( 2, P2, 'SP' ) ) THEN
+*
+*        SP: Symmetric indefinite packed,
+*            with partial (Bunch-Kaufman) pivoting algorithm
 *
          IF( LSAME( C3, 'Y' ) ) THEN
             WRITE( IOUNIT, FMT = 9992 )PATH, 'Symmetric'
@@ -224,10 +373,82 @@
          WRITE( IOUNIT, FMT = 9955 )8
          WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
 *
-      ELSE IF( LSAMEN( 2, P2, 'HE' ) .OR. LSAMEN( 2, P2, 'HP' ) ) THEN
+      ELSE IF( LSAMEN( 2, P2, 'HA' )  ) THEN
 *
-*        HE: Hermitian indefinite full
-*        HP: Hermitian indefinite packed
+*        HA: Hermitian,
+*            with Assen Algorithm
+*
+         WRITE( IOUNIT, FMT = 9992 )PATH, 'Hermitian'
+*
+         WRITE( IOUNIT, FMT = '( '' Matrix types:'' )' )
+         WRITE( IOUNIT, FMT = 9972 )
+*
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 9953 )1
+         WRITE( IOUNIT, FMT = 9961 )2
+         WRITE( IOUNIT, FMT = 9960 )3
+         WRITE( IOUNIT, FMT = 9960 )4
+         WRITE( IOUNIT, FMT = 9959 )5
+         WRITE( IOUNIT, FMT = 9958 )6
+         WRITE( IOUNIT, FMT = 9956 )7
+         WRITE( IOUNIT, FMT = 9957 )8
+         WRITE( IOUNIT, FMT = 9955 )9
+         WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
+*
+      ELSE IF( LSAMEN( 2, P2, 'HE' )  ) THEN
+*
+*        HE: Hermitian indefinite full,
+*            with partial (Bunch-Kaufman) pivoting algorithm
+*
+         WRITE( IOUNIT, FMT = 9992 )PATH, 'Hermitian'
+*
+         WRITE( IOUNIT, FMT = '( '' Matrix types:'' )' )
+         WRITE( IOUNIT, FMT = 9972 )
+*
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 9953 )1
+         WRITE( IOUNIT, FMT = 9961 )2
+         WRITE( IOUNIT, FMT = 9960 )3
+         WRITE( IOUNIT, FMT = 9960 )4
+         WRITE( IOUNIT, FMT = 9959 )5
+         WRITE( IOUNIT, FMT = 9958 )6
+         WRITE( IOUNIT, FMT = 9956 )7
+         WRITE( IOUNIT, FMT = 9957 )8
+         WRITE( IOUNIT, FMT = 9955 )9
+         WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
+*
+      ELSE IF( LSAMEN( 2, P2, 'HR' ) .OR. LSAMEN( 2, P2, 'HR' ) ) THEN
+*
+*        HR: Hermitian indefinite full,
+*            with rook (bounded Bunch-Kaufman) pivoting algorithm
+*
+*        HK: Hermitian indefinite full,
+*            with rook (bounded Bunch-Kaufman) pivoting algorithm,
+*            ( new storage format for factors:
+*              L and diagonal of D is stored in A,
+*              subdiagonal of D is stored in E )
+*
+         WRITE( IOUNIT, FMT = 9892 )PATH, 'Hermitian'
+*
+         WRITE( IOUNIT, FMT = '( '' Matrix types:'' )' )
+         WRITE( IOUNIT, FMT = 9972 )
+*
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 9953 )1
+         WRITE( IOUNIT, FMT = 9961 )2
+         WRITE( IOUNIT, FMT = 9927 )3
+         WRITE( IOUNIT, FMT = 9928 )
+         WRITE( IOUNIT, FMT = 9926 )4
+         WRITE( IOUNIT, FMT = 9928 )
+         WRITE( IOUNIT, FMT = 9960 )5
+         WRITE( IOUNIT, FMT = 9959 )6
+         WRITE( IOUNIT, FMT = 9955 )7
+         WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
+*
+      ELSE IF( LSAMEN( 2, P2, 'HP' ) ) THEN
+*
+*        HP: Hermitian indefinite packed,
+*            with partial (Bunch-Kaufman) pivoting algorithm
 *
          IF( LSAME( C3, 'E' ) ) THEN
             WRITE( IOUNIT, FMT = 9992 )PATH, 'Hermitian'
@@ -260,7 +481,7 @@
             SUBNAM = PATH( 1: 1 ) // 'LATPS'
          END IF
          WRITE( IOUNIT, FMT = 9966 )PATH
-         WRITE( IOUNIT, FMT = 9965 )SUBNAM
+         WRITE( IOUNIT, FMT = 9965 )SUBNAM(1:LEN_TRIM( SUBNAM ))
          WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
          WRITE( IOUNIT, FMT = 9961 )1
          WRITE( IOUNIT, FMT = 9960 )2
@@ -269,7 +490,7 @@
          WRITE( IOUNIT, FMT = 9957 )5
          WRITE( IOUNIT, FMT = 9956 )6
          WRITE( IOUNIT, FMT = 9955 )7
-         WRITE( IOUNIT, FMT = 9951 )SUBNAM, 8
+         WRITE( IOUNIT, FMT = 9951 )SUBNAM(1:LEN_TRIM( SUBNAM )), 8
          WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
 *
       ELSE IF( LSAMEN( 2, P2, 'TB' ) ) THEN
@@ -279,7 +500,7 @@
          WRITE( IOUNIT, FMT = 9988 )PATH
          SUBNAM = PATH( 1: 1 ) // 'LATBS'
          WRITE( IOUNIT, FMT = 9964 )PATH
-         WRITE( IOUNIT, FMT = 9963 )SUBNAM
+         WRITE( IOUNIT, FMT = 9963 )SUBNAM(1:LEN_TRIM( SUBNAM ))
          WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
          WRITE( IOUNIT, FMT = 9960 )1
          WRITE( IOUNIT, FMT = 9959 )2
@@ -287,7 +508,7 @@
          WRITE( IOUNIT, FMT = 9957 )4
          WRITE( IOUNIT, FMT = 9956 )5
          WRITE( IOUNIT, FMT = 9955 )6
-         WRITE( IOUNIT, FMT = 9951 )SUBNAM, 7
+         WRITE( IOUNIT, FMT = 9951 )SUBNAM(1:LEN_TRIM( SUBNAM )), 7
          WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
 *
       ELSE IF( LSAMEN( 2, P2, 'QR' ) ) THEN
@@ -299,12 +520,14 @@
          WRITE( IOUNIT, FMT = 9970 )
          WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
          WRITE( IOUNIT, FMT = 9950 )1
+         WRITE( IOUNIT, FMT = 6950 )8
          WRITE( IOUNIT, FMT = 9946 )2
          WRITE( IOUNIT, FMT = 9944 )3, 'M'
          WRITE( IOUNIT, FMT = 9943 )4, 'M'
          WRITE( IOUNIT, FMT = 9942 )5, 'M'
          WRITE( IOUNIT, FMT = 9941 )6, 'M'
          WRITE( IOUNIT, FMT = 9960 )7
+         WRITE( IOUNIT, FMT = 6660 )9
          WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
 *
       ELSE IF( LSAMEN( 2, P2, 'LQ' ) ) THEN
@@ -376,6 +599,7 @@
 *
          WRITE( IOUNIT, FMT = 9985 )PATH
          WRITE( IOUNIT, FMT = 9968 )
+         WRITE( IOUNIT, FMT = 9929 )C1
          WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
          WRITE( IOUNIT, FMT = 9940 )1
          WRITE( IOUNIT, FMT = 9937 )2
@@ -384,18 +608,19 @@
 *
       ELSE IF( LSAMEN( 2, P2, 'LS' ) ) THEN
 *
-*        LS:  Least Squares driver routines
+*        LS:  Least Squares driver routines for
+*             LS, LSD, LSS, LSX and LSY.
 *
          WRITE( IOUNIT, FMT = 9984 )PATH
          WRITE( IOUNIT, FMT = 9967 )
-         WRITE( IOUNIT, FMT = 9936 )C1, C1, C1
+         WRITE( IOUNIT, FMT = 9921 )C1, C1, C1, C1
          WRITE( IOUNIT, FMT = 9935 )1
          WRITE( IOUNIT, FMT = 9931 )2
          WRITE( IOUNIT, FMT = 9933 )3
          WRITE( IOUNIT, FMT = 9935 )4
          WRITE( IOUNIT, FMT = 9934 )5
          WRITE( IOUNIT, FMT = 9932 )6
-         WRITE( IOUNIT, FMT = 9930 )
+         WRITE( IOUNIT, FMT = 9920 )
          WRITE( IOUNIT, FMT = '( '' Messages:'' )' )
 *
       ELSE IF( LSAMEN( 2, P2, 'LU' ) ) THEN
@@ -428,6 +653,71 @@
          WRITE( IOUNIT, FMT = '( '' Matrix types:'' )' )
          WRITE( IOUNIT, FMT = 9970 )
          WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+*
+      ELSE IF( LSAMEN( 2, P2, 'QT' ) ) THEN
+*
+*        QRT (general matrices)
+*
+         WRITE( IOUNIT, FMT = 8000 ) PATH
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 8011 ) 1
+         WRITE( IOUNIT, FMT = 8012 ) 2
+         WRITE( IOUNIT, FMT = 8013 ) 3
+         WRITE( IOUNIT, FMT = 8014 ) 4
+         WRITE( IOUNIT, FMT = 8015 ) 5
+         WRITE( IOUNIT, FMT = 8016 ) 6
+*
+      ELSE IF( LSAMEN( 2, P2, 'QX' ) ) THEN
+*
+*        QRT (triangular-pentagonal)
+*
+         WRITE( IOUNIT, FMT = 8001 ) PATH
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 8017 ) 1
+         WRITE( IOUNIT, FMT = 8018 ) 2
+         WRITE( IOUNIT, FMT = 8019 ) 3
+         WRITE( IOUNIT, FMT = 8020 ) 4
+         WRITE( IOUNIT, FMT = 8021 ) 5
+         WRITE( IOUNIT, FMT = 8022 ) 6
+*
+      ELSE IF( LSAMEN( 2, P2, 'TQ' ) ) THEN
+*
+*        QRT (triangular-pentagonal)
+*
+         WRITE( IOUNIT, FMT = 8002 ) PATH
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 8023 ) 1
+         WRITE( IOUNIT, FMT = 8024 ) 2
+         WRITE( IOUNIT, FMT = 8025 ) 3
+         WRITE( IOUNIT, FMT = 8026 ) 4
+         WRITE( IOUNIT, FMT = 8027 ) 5
+         WRITE( IOUNIT, FMT = 8028 ) 6
+*
+      ELSE IF( LSAMEN( 2, P2, 'XQ' ) ) THEN
+*
+*        QRT (triangular-pentagonal)
+*
+         WRITE( IOUNIT, FMT = 8003 ) PATH
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 8029 ) 1
+         WRITE( IOUNIT, FMT = 8030 ) 2
+         WRITE( IOUNIT, FMT = 8031 ) 3
+         WRITE( IOUNIT, FMT = 8032 ) 4
+         WRITE( IOUNIT, FMT = 8033 ) 5
+         WRITE( IOUNIT, FMT = 8034 ) 6
+*
+      ELSE IF( LSAMEN( 2, P2, 'TS' ) ) THEN
+*
+*        QRT (triangular-pentagonal)
+*
+         WRITE( IOUNIT, FMT = 8004 ) PATH
+         WRITE( IOUNIT, FMT = '( '' Test ratios:'' )' )
+         WRITE( IOUNIT, FMT = 8035 ) 1
+         WRITE( IOUNIT, FMT = 8036 ) 2
+         WRITE( IOUNIT, FMT = 8037 ) 3
+         WRITE( IOUNIT, FMT = 8038 ) 4
+         WRITE( IOUNIT, FMT = 8039 ) 5
+         WRITE( IOUNIT, FMT = 8040 ) 6
 *
       ELSE
 *
@@ -446,8 +736,14 @@
      $       )
  9994 FORMAT( / 1X, A3, ':  ', A9, ' positive definite band matrices' )
  9993 FORMAT( / 1X, A3, ':  ', A9, ' positive definite tridiagonal' )
- 9992 FORMAT( / 1X, A3, ':  ', A9, ' indefinite matrices' )
- 9991 FORMAT( / 1X, A3, ':  ', A9, ' indefinite packed matrices' )
+ 9992 FORMAT( / 1X, A3, ':  ', A9, ' indefinite matrices',
+     $      ', partial (Bunch-Kaufman) pivoting' )
+ 9991 FORMAT( / 1X, A3, ':  ', A9, ' indefinite packed matrices',
+     $      ', partial (Bunch-Kaufman) pivoting' )
+ 9892 FORMAT( / 1X, A3, ':  ', A9, ' indefinite matrices',
+     $      ', "rook" (bounded Bunch-Kaufman) pivoting' )
+ 9891 FORMAT( / 1X, A3, ':  ', A9, ' indefinite packed matrices',
+     $      ', "rook" (bounded Bunch-Kaufman) pivoting' )
  9990 FORMAT( / 1X, A3, ':  Triangular matrices' )
  9989 FORMAT( / 1X, A3, ':  Triangular packed matrices' )
  9988 FORMAT( / 1X, A3, ':  Triangular band matrices' )
@@ -460,6 +756,14 @@
  9982 FORMAT( / 1X, A3, ':  Cholesky factorization variants' )
  9981 FORMAT( / 1X, A3, ':  QR factorization variants' )
  9980 FORMAT( / 1X, A3, ':  No header available' )
+ 8000 FORMAT( / 1X, A3, ':  QRT factorization for general matrices' )
+ 8001 FORMAT( / 1X, A3, ':  QRT factorization for ',
+     $       'triangular-pentagonal matrices' )
+ 8002 FORMAT( / 1X, A3, ':  LQT factorization for general matrices' )
+ 8003 FORMAT( / 1X, A3, ':  LQT factorization for ',
+     $       'triangular-pentagonal matrices' )
+ 8004 FORMAT( / 1X, A3, ':  TS factorization for ',
+     $       'tall-skiny or short-wide matrices' )
 *
 *     GE matrix types
 *
@@ -532,6 +836,21 @@
      $      '*5. Middle row and column zero', / 3X,
      $      '(* - tests error exits, no test ratios are computed)' )
 *
+*     PS matrix types
+*
+ 8973 FORMAT( 4X, '1. Diagonal', / 4X, '2. Random, CNDNUM = 2', 14X,
+     $      / 3X, '*3. Nonzero eigenvalues of: D(1:RANK-1)=1 and ',
+     $      'D(RANK) = 1.0/', A4, / 3X,
+     $      '*4. Nonzero eigenvalues of: D(1)=1 and ',
+     $      ' D(2:RANK) = 1.0/', A4, / 3X,
+     $      '*5. Nonzero eigenvalues of: D(I) = ', A4,
+     $      '**(-(I-1)/(RANK-1)) ', ' I=1:RANK', / 4X,
+     $      '6. Random, CNDNUM = sqrt(0.1/EPS)', / 4X,
+     $      '7. Random, CNDNUM = 0.1/EPS', / 4X,
+     $      '8. Scaled near underflow', / 4X, '9. Scaled near overflow',
+     $      / 3X, '(* - Semi-definite tests )' )
+ 8972 FORMAT( 3X, 'RANK minus computed rank, returned by ', A, 'PSTRF' )
+*
 *     PB matrix types
 *
  9973 FORMAT( 4X, '1. Random, CNDNUM = 2', 14X,
@@ -545,7 +864,7 @@
      $      '(* - tests error exits from ', A3,
      $      'TRF, no test ratios are computed)' )
 *
-*     SSY, SSP, CHE, CHP matrix types
+*     SSY, SSR, SSP, CHE, CHR, CHP matrix types
 *
  9972 FORMAT( 4X, '1. Diagonal', 24X,
      $      '6. Last n/2 rows and columns zero', / 4X,
@@ -558,7 +877,7 @@
      $      '5. Middle row and column zero', 5X,
      $      '10. Scaled near overflow' )
 *
-*     CSY, CSP matrix types
+*     CSY, CSR, CSP matrix types
 *
  9971 FORMAT( 4X, '1. Diagonal', 24X,
      $      '7. Random, CNDNUM = sqrt(0.1/EPS)', / 4X,
@@ -612,7 +931,7 @@
      $      '9. Unit, CNDNUM = sqrt(0.1/EPS)', / 4X,
      $      '5. Scaled near underflow', 10X,
      $      '10. Unit, CNDNUM = 0.1/EPS' )
- 9965 FORMAT( ' Special types for testing ', A6, ':', / 3X,
+ 9965 FORMAT( ' Special types for testing ', A, ':', / 3X,
      $      '11. Matrix elements are O(1), large right hand side', / 3X,
      $      '12. First diagonal causes overflow,',
      $      ' offdiagonal column norms < 1', / 3X,
@@ -635,7 +954,7 @@
      $      '4. Scaled near underflow', 11X,
      $      '9. Unit, CNDNUM = 0.1/EPS', / 4X,
      $      '5. Scaled near overflow' )
- 9963 FORMAT( ' Special types for testing ', A6, ':', / 3X,
+ 9963 FORMAT( ' Special types for testing ', A, ':', / 3X,
      $      '10. Matrix elements are O(1), large right hand side', / 3X,
      $      '11. First diagonal causes overflow,',
      $      ' offdiagonal column norms < 1', / 3X,
@@ -654,6 +973,7 @@
      $      '( N * norm(A) * norm(AINV) * EPS )' )
  9960 FORMAT( 3X, I2, ': norm( B - A * X )  / ',
      $      '( norm(A) * norm(X) * EPS )' )
+ 6660 FORMAT( 3X, I2, ': diagonal is not non-negative')
  9959 FORMAT( 3X, I2, ': norm( X - XACT )   / ',
      $      '( norm(XACT) * CNDNUM * EPS )' )
  9958 FORMAT( 3X, I2, ': norm( X - XACT )   / ',
@@ -665,15 +985,21 @@
  9954 FORMAT( 3X, I2, ': norm( U'' * U - A ) / ( N * norm(A) * EPS )',
      $      ', or', / 7X, 'norm( L * L'' - A ) / ( N * norm(A) * EPS )'
      $       )
+ 8950 FORMAT( 3X,
+     $      'norm( P * U'' * U * P'' - A ) / ( N * norm(A) * EPS )',
+     $      ', or', / 3X,
+     $      'norm( P * L * L'' * P'' - A ) / ( N * norm(A) * EPS )' )
  9953 FORMAT( 3X, I2, ': norm( U*D*U'' - A ) / ( N * norm(A) * EPS )',
      $      ', or', / 7X, 'norm( L*D*L'' - A ) / ( N * norm(A) * EPS )'
      $       )
  9952 FORMAT( 3X, I2, ': norm( U''*D*U - A ) / ( N * norm(A) * EPS )',
      $      ', or', / 7X, 'norm( L*D*L'' - A ) / ( N * norm(A) * EPS )'
      $       )
- 9951 FORMAT( ' Test ratio for ', A6, ':', / 3X, I2,
+ 9951 FORMAT( ' Test ratio for ', A, ':', / 3X, I2,
      $      ': norm( s*b - A*x )  / ( norm(A) * norm(x) * EPS )' )
  9950 FORMAT( 3X, I2, ': norm( R - Q'' * A ) / ( M * norm(A) * EPS )' )
+ 6950 FORMAT( 3X, I2, ': norm( R - Q'' * A ) / ( M * norm(A) * EPS )
+     $       [RFPG]' )
  9949 FORMAT( 3X, I2, ': norm( L - A * Q'' ) / ( N * norm(A) * EPS )' )
  9948 FORMAT( 3X, I2, ': norm( L - Q'' * A ) / ( M * norm(A) * EPS )' )
  9947 FORMAT( 3X, I2, ': norm( R - A * Q'' ) / ( N * norm(A) * EPS )' )
@@ -694,8 +1020,6 @@
  9938 FORMAT( 3X, I2, ': norm( I - Q''*Q )      / ( M * EPS )' )
  9937 FORMAT( 3X, I2, ': norm( A - R*Q )       / ( M * norm(A) * EPS )'
      $       )
- 9936 FORMAT( ' Test ratios (1-2: ', A1, 'GELS, 3-6: ', A1,
-     $      'GELSS, 7-10: ', A1, 'GELSX):' )
  9935 FORMAT( 3X, I2, ': norm( B - A * X )   / ',
      $      '( max(M,N) * norm(A) * norm(X) * EPS )' )
  9934 FORMAT( 3X, I2, ': norm( (A*X-B)'' *A ) / ',
@@ -709,7 +1033,54 @@
      $      'otherwise', / 7X,
      $      'check if X is in the row space of A or A'' ',
      $      '(overdetermined case)' )
- 9930 FORMAT( 3X, ' 7-10: same as 3-6' )
+ 9929 FORMAT( ' Test ratios (1-3: ', A1, 'TZRZF):' )
+ 9920 FORMAT( 3X, ' 7-10: same as 3-6', 3X, ' 11-14: same as 3-6' )
+ 9921 FORMAT( ' Test ratios:', / '    (1-2: ', A1, 'GELS, 3-6: ', A1,
+     $      'GELSY, 7-10: ', A1, 'GELSS, 11-14: ', A1, 'GELSD, 15-16: '
+     $        A1, 'GETSLS)')
+ 9928 FORMAT( 7X, 'where ALPHA = ( 1 + SQRT( 17 ) ) / 8' )
+ 9927 FORMAT( 3X, I2, ': ABS( Largest element in L )', / 12X,
+     $      ' - ( 1 / ( 1 - ALPHA ) ) + THRESH' )
+ 9926 FORMAT( 3X, I2, ': Largest 2-Norm of 2-by-2 pivots', / 12X,
+     $      ' - ( ( 1 + ALPHA ) / ( 1 - ALPHA ) ) + THRESH' )
+ 8011 FORMAT(3X,I2,': norm( R - Q''*A ) / ( M * norm(A) * EPS )' )
+ 8012 FORMAT(3X,I2,': norm( I - Q''*Q ) / ( M * EPS )' )
+ 8013 FORMAT(3X,I2,': norm( Q*C - Q*C ) / ( M * norm(C) * EPS )' )
+ 8014 FORMAT(3X,I2,': norm( Q''*C - Q''*C ) / ( M * norm(C) * EPS )')
+ 8015 FORMAT(3X,I2,': norm( C*Q - C*Q ) / ( M * norm(C) * EPS )' )
+ 8016 FORMAT(3X,I2,': norm( C*Q'' - C*Q'' ) / ( M * norm(C) * EPS )')
+ 8017 FORMAT(3X,I2,': norm( R - Q''*A ) / ( (M+N) * norm(A) * EPS )' )
+ 8018 FORMAT(3X,I2,': norm( I - Q''*Q ) / ( (M+N) * EPS )' )
+ 8019 FORMAT(3X,I2,': norm( Q*C - Q*C ) / ( (M+N) * norm(C) * EPS )' )
+ 8020 FORMAT(3X,I2,
+     $ ': norm( Q''*C - Q''*C ) / ( (M+N) * norm(C) * EPS )')
+ 8021 FORMAT(3X,I2,': norm( C*Q - C*Q ) / ( (M+N) * norm(C) * EPS )' )
+ 8022 FORMAT(3X,I2,
+     $ ': norm( C*Q'' - C*Q'' ) / ( (M+N) * norm(C) * EPS )')
+ 8023 FORMAT(3X,I2,': norm( L - A*Q'' ) / ( (M+N) * norm(A) * EPS )' )
+ 8024 FORMAT(3X,I2,': norm( I - Q*Q'' ) / ( (M+N) * EPS )' )
+ 8025 FORMAT(3X,I2,': norm( Q*C - Q*C ) / ( (M+N) * norm(C) * EPS )' )
+ 8026 FORMAT(3X,I2,
+     $ ': norm( Q''*C - Q''*C ) / ( (M+N) * norm(C) * EPS )')
+ 8027 FORMAT(3X,I2,': norm( C*Q - C*Q ) / ( (M+N) * norm(C) * EPS )' )
+ 8028 FORMAT(3X,I2,
+     $ ': norm( C*Q'' - C*Q'' ) / ( (M+N) * norm(C) * EPS )')
+ 8029 FORMAT(3X,I2,': norm( L - A*Q'' ) / ( (M+N) * norm(A) * EPS )' )
+ 8030 FORMAT(3X,I2,': norm( I - Q*Q'' ) / ( (M+N) * EPS )' )
+ 8031 FORMAT(3X,I2,': norm( Q*C - Q*C ) / ( (M+N) * norm(C) * EPS )' )
+ 8032 FORMAT(3X,I2,
+     $ ': norm( Q''*C - Q''*C ) / ( (M+N) * norm(C) * EPS )')
+ 8033 FORMAT(3X,I2,': norm( C*Q - C*Q ) / ( (M+N) * norm(C) * EPS )' )
+ 8034 FORMAT(3X,I2,
+     $ ': norm( C*Q'' - C*Q'' ) / ( (M+N) * norm(C) * EPS )')
+ 8035 FORMAT(3X,I2,': norm( R - Q''*A ) / ( (M+N) * norm(A) * EPS )' )
+ 8036 FORMAT(3X,I2,': norm( I - Q''*Q ) / ( (M+N) * EPS )' )
+ 8037 FORMAT(3X,I2,': norm( Q*C - Q*C ) / ( (M+N) * norm(C) * EPS )' )
+ 8038 FORMAT(3X,I2,
+     $ ': norm( Q''*C - Q''*C ) / ( (M+N) * norm(C) * EPS )')
+ 8039 FORMAT(3X,I2,': norm( C*Q - C*Q ) / ( (M+N) * norm(C) * EPS )' )
+ 8040 FORMAT(3X,I2,
+     $ ': norm( C*Q'' - C*Q'' ) / ( (M+N) * norm(C) * EPS )')
 *
       RETURN
 *
