@@ -1,11 +1,176 @@
+*> \brief \b SDRVPP
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SDRVPP( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
+*                          A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
+*                          RWORK, IWORK, NOUT )
+*
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            NMAX, NN, NOUT, NRHS
+*       REAL               THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            IWORK( * ), NVAL( * )
+*       REAL               A( * ), AFAC( * ), ASAV( * ), B( * ),
+*      $                   BSAV( * ), RWORK( * ), S( * ), WORK( * ),
+*      $                   X( * ), XACT( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SDRVPP tests the driver routines SPPSV and -SVX.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix dimension N.
+*> \endverbatim
+*>
+*> \param[in] NRHS
+*> \verbatim
+*>          NRHS is INTEGER
+*>          The number of right hand side vectors to be generated for
+*>          each linear system.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is REAL
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[in] NMAX
+*> \verbatim
+*>          NMAX is INTEGER
+*>          The maximum value permitted for N, used in dimensioning the
+*>          work arrays.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is REAL array, dimension
+*>                      (NMAX*(NMAX+1)/2)
+*> \endverbatim
+*>
+*> \param[out] AFAC
+*> \verbatim
+*>          AFAC is REAL array, dimension
+*>                      (NMAX*(NMAX+1)/2)
+*> \endverbatim
+*>
+*> \param[out] ASAV
+*> \verbatim
+*>          ASAV is REAL array, dimension
+*>                      (NMAX*(NMAX+1)/2)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is REAL array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] BSAV
+*> \verbatim
+*>          BSAV is REAL array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is REAL array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is REAL array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] S
+*> \verbatim
+*>          S is REAL array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is REAL array, dimension
+*>                      (NMAX*max(3,NRHS))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is REAL array, dimension (NMAX+2*NRHS)
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup single_lin
+*
+*  =====================================================================
       SUBROUTINE SDRVPP( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
      $                   A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -20,70 +185,6 @@
      $                   X( * ), XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SDRVPP tests the driver routines SPPSV and -SVX.
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix dimension N.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) REAL
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  NMAX    (input) INTEGER
-*          The maximum value permitted for N, used in dimensioning the
-*          work arrays.
-*
-*  A       (workspace) REAL array, dimension
-*                      (NMAX*(NMAX+1)/2)
-*
-*  AFAC    (workspace) REAL array, dimension
-*                      (NMAX*(NMAX+1)/2)
-*
-*  ASAV    (workspace) REAL array, dimension
-*                      (NMAX*(NMAX+1)/2)
-*
-*  B       (workspace) REAL array, dimension (NMAX*NRHS)
-*
-*  BSAV    (workspace) REAL array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) REAL array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) REAL array, dimension (NMAX*NRHS)
-*
-*  S       (workspace) REAL array, dimension (NMAX)
-*
-*  WORK    (workspace) REAL array, dimension
-*                      (NMAX*max(3,NRHS))
-*
-*  RWORK   (workspace) REAL array, dimension (NMAX+2*NRHS)
-*
-*  IWORK   (workspace) INTEGER array, dimension (NMAX)
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -122,7 +223,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -141,7 +242,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'S'
+      PATH( 1: 1 ) = 'Single precision'
       PATH( 2: 3 ) = 'PP'
       NRUN = 0
       NFAIL = 0
@@ -158,7 +259,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 150 IN = 1, NN
+      DO 140 IN = 1, NN
          N = NVAL( IN )
          LDA = MAX( N, 1 )
          NPP = N*( N+1 ) / 2
@@ -167,22 +268,22 @@
          IF( N.LE.0 )
      $      NIMAT = 1
 *
-         DO 140 IMAT = 1, NIMAT
+         DO 130 IMAT = 1, NIMAT
 *
 *           Do the tests only if DOTYPE( IMAT ) is true.
 *
             IF( .NOT.DOTYPE( IMAT ) )
-     $         GO TO 140
+     $         GO TO 130
 *
 *           Skip types 3, 4, or 5 if the matrix size is too small.
 *
             ZEROT = IMAT.GE.3 .AND. IMAT.LE.5
             IF( ZEROT .AND. N.LT.IMAT-2 )
-     $         GO TO 140
+     $         GO TO 130
 *
 *           Do first for UPLO = 'U', then for UPLO = 'L'
 *
-            DO 130 IUPLO = 1, 2
+            DO 120 IUPLO = 1, 2
                UPLO = UPLOS( IUPLO )
                PACKIT = PACKS( IUPLO )
 *
@@ -203,7 +304,7 @@
                IF( INFO.NE.0 ) THEN
                   CALL ALAERH( PATH, 'SLATMS', INFO, 0, UPLO, N, N, -1,
      $                         -1, -1, IMAT, NFAIL, NERRS, NOUT )
-                  GO TO 130
+                  GO TO 120
                END IF
 *
 *              For types 3-5, zero one row and column of the matrix to
@@ -249,7 +350,7 @@
 *
                CALL SCOPY( NPP, A, 1, ASAV, 1 )
 *
-               DO 120 IEQUED = 1, 2
+               DO 110 IEQUED = 1, 2
                   EQUED = EQUEDS( IEQUED )
                   IF( IEQUED.EQ.1 ) THEN
                      NFACT = 3
@@ -257,7 +358,7 @@
                      NFACT = 1
                   END IF
 *
-                  DO 110 IFACT = 1, NFACT
+                  DO 100 IFACT = 1, NFACT
                      FACT = FACTS( IFACT )
                      PREFAC = LSAME( FACT, 'F' )
                      NOFACT = LSAME( FACT, 'N' )
@@ -265,7 +366,7 @@
 *
                      IF( ZEROT ) THEN
                         IF( PREFAC )
-     $                     GO TO 110
+     $                     GO TO 100
                         RCONDC = ZERO
 *
                      ELSE IF( .NOT.LSAME( FACT, 'N' ) ) THEN
@@ -322,7 +423,6 @@
                            RCONDC = ( ONE / ANORM ) / AINVNM
                         END IF
                      END IF
-   60                CONTINUE
 *
 *                    Restore the matrix A.
 *
@@ -356,9 +456,9 @@
                            CALL ALAERH( PATH, 'SPPSV ', INFO, IZERO,
      $                                  UPLO, N, N, -1, -1, NRHS, IMAT,
      $                                  NFAIL, NERRS, NOUT )
-                           GO TO 80
+                           GO TO 70
                         ELSE IF( INFO.NE.0 ) THEN
-                           GO TO 80
+                           GO TO 70
                         END IF
 *
 *                       Reconstruct matrix from factors and compute
@@ -383,7 +483,7 @@
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 70 K = 1, NT
+                        DO 60 K = 1, NT
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -391,9 +491,9 @@
      $                           N, IMAT, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
-   70                   CONTINUE
+   60                   CONTINUE
                         NRUN = NRUN + NT
-   80                   CONTINUE
+   70                   CONTINUE
                      END IF
 *
 *                    --- Test SPPSVX ---
@@ -424,7 +524,7 @@
                         CALL ALAERH( PATH, 'SPPSVX', INFO, IZERO,
      $                               FACT // UPLO, N, N, -1, -1, NRHS,
      $                               IMAT, NFAIL, NERRS, NOUT )
-                        GO TO 100
+                        GO TO 90
                      END IF
 *
                      IF( INFO.EQ.0 ) THEN
@@ -477,7 +577,7 @@
 *                    Print information about the tests that did not pass
 *                    the threshold.
 *
-                     DO 90 K = K1, 6
+                     DO 80 K = K1, 6
                         IF( RESULT( K ).GE.THRESH ) THEN
                            IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                        CALL ALADHD( NOUT, PATH )
@@ -490,24 +590,24 @@
                            END IF
                            NFAIL = NFAIL + 1
                         END IF
-   90                CONTINUE
+   80                CONTINUE
                      NRUN = NRUN + 7 - K1
-  100                CONTINUE
-  110             CONTINUE
-  120          CONTINUE
-  130       CONTINUE
-  140    CONTINUE
-  150 CONTINUE
+   90                CONTINUE
+  100             CONTINUE
+  110          CONTINUE
+  120       CONTINUE
+  130    CONTINUE
+  140 CONTINUE
 *
 *     Print a summary of the results.
 *
       CALL ALASVM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( 1X, A6, ', UPLO=''', A1, ''', N =', I5, ', type ', I1,
+ 9999 FORMAT( 1X, A, ', UPLO=''', A1, ''', N =', I5, ', type ', I1,
      $      ', test(', I1, ')=', G12.5 )
- 9998 FORMAT( 1X, A6, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
+ 9998 FORMAT( 1X, A, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
      $      ', type ', I1, ', test(', I1, ')=', G12.5 )
- 9997 FORMAT( 1X, A6, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
+ 9997 FORMAT( 1X, A, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
      $      ', EQUED=''', A1, ''', type ', I1, ', test(', I1, ')=',
      $      G12.5 )
       RETURN
