@@ -1,34 +1,74 @@
+*> \brief \b SERRQP
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SERRQP( PATH, NUNIT )
+*
+*       .. Scalar Arguments ..
+*       CHARACTER*3        PATH
+*       INTEGER            NUNIT
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SERRQP tests the error exits for SGEQP3.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] PATH
+*> \verbatim
+*>          PATH is CHARACTER*3
+*>          The LAPACK path name for the routines to be tested.
+*> \endverbatim
+*>
+*> \param[in] NUNIT
+*> \verbatim
+*>          NUNIT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup single_lin
+*
+*  =====================================================================
       SUBROUTINE SERRQP( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SERRQP tests the error exits for SGEQPF and SGEQP3.
-*
-*  Arguments
-*  =========
-*
-*  PATH    (input) CHARACTER*3
-*          The LAPACK path name for the routines to be tested.
-*
-*  NUNIT   (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
       INTEGER            NMAX
-      PARAMETER          ( NMAX = 2 )
+      PARAMETER          ( NMAX = 3 )
 *     ..
 *     .. Local Scalars ..
       CHARACTER*2        C2
@@ -43,11 +83,11 @@
       EXTERNAL           LSAMEN
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALAESM, CHKXER, SGEQP3, SGEQPF
+      EXTERNAL           ALAESM, CHKXER, SGEQP3
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NOUT
 *     ..
 *     .. Common blocks ..
@@ -70,19 +110,6 @@
 *
 *        Test error exits for QR factorization with pivoting
 *
-*        SGEQPF
-*
-         SRNAMT = 'SGEQPF'
-         INFOT = 1
-         CALL SGEQPF( -1, 0, A, 1, IP, TAU, W, INFO )
-         CALL CHKXER( 'SGEQPF', INFOT, NOUT, LERR, OK )
-         INFOT = 2
-         CALL SGEQPF( 0, -1, A, 1, IP, TAU, W, INFO )
-         CALL CHKXER( 'SGEQPF', INFOT, NOUT, LERR, OK )
-         INFOT = 4
-         CALL SGEQPF( 2, 0, A, 1, IP, TAU, W, INFO )
-         CALL CHKXER( 'SGEQPF', INFOT, NOUT, LERR, OK )
-*
 *        SGEQP3
 *
          SRNAMT = 'SGEQP3'
@@ -93,10 +120,10 @@
          CALL SGEQP3( 1, -1, A, 1, IP, TAU, W, LW, INFO )
          CALL CHKXER( 'SGEQP3', INFOT, NOUT, LERR, OK )
          INFOT = 4
-         CALL SGEQP3( 1, 2, A, 0, IP, TAU, W, LW, INFO )
+         CALL SGEQP3( 2, 3, A, 1, IP, TAU, W, LW, INFO )
          CALL CHKXER( 'SGEQP3', INFOT, NOUT, LERR, OK )
          INFOT = 8
-         CALL SGEQP3( 2, 2, A, 2, IP, TAU, W, LW-1, INFO )
+         CALL SGEQP3( 2, 2, A, 2, IP, TAU, W, LW-10, INFO )
          CALL CHKXER( 'SGEQP3', INFOT, NOUT, LERR, OK )
       END IF
 *
