@@ -1,9 +1,98 @@
+*> \brief \b SQRT12
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       REAL             FUNCTION SQRT12( M, N, A, LDA, S, WORK, LWORK )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            LDA, LWORK, M, N
+*       ..
+*       .. Array Arguments ..
+*       REAL               A( LDA, * ), S( * ), WORK( LWORK )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SQRT12 computes the singular values `svlues' of the upper trapezoid
+*> of A(1:M,1:N) and returns the ratio
+*>
+*>      || s - svlues||/(||svlues||*eps*max(M,N))
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] M
+*> \verbatim
+*>          M is INTEGER
+*>          The number of rows of the matrix A.
+*> \endverbatim
+*>
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>          The number of columns of the matrix A.
+*> \endverbatim
+*>
+*> \param[in] A
+*> \verbatim
+*>          A is REAL array, dimension (LDA,N)
+*>          The M-by-N matrix A. Only the upper trapezoid is referenced.
+*> \endverbatim
+*>
+*> \param[in] LDA
+*> \verbatim
+*>          LDA is INTEGER
+*>          The leading dimension of the array A.
+*> \endverbatim
+*>
+*> \param[in] S
+*> \verbatim
+*>          S is REAL array, dimension (min(M,N))
+*>          The singular values of the matrix A.
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is REAL array, dimension (LWORK)
+*> \endverbatim
+*>
+*> \param[in] LWORK
+*> \verbatim
+*>          LWORK is INTEGER
+*>          The length of the array WORK. LWORK >= max(M*N + 4*min(M,N) +
+*>          max(M,N), M*N+2*MIN( M, N )+4*N).
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup single_lin
+*
+*  =====================================================================
       REAL             FUNCTION SQRT12( M, N, A, LDA, S, WORK, LWORK )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       INTEGER            LDA, LWORK, M, N
@@ -12,38 +101,6 @@
       REAL               A( LDA, * ), S( * ), WORK( LWORK )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SQRT12 computes the singular values `svlues' of the upper trapezoid
-*  of A(1:M,1:N) and returns the ratio
-*
-*       || s - svlues||/(||svlues||*eps*max(M,N))
-*
-*  Arguments
-*  =========
-*
-*  M       (input) INTEGER
-*          The number of rows of the matrix A.
-*
-*  N       (input) INTEGER
-*          The number of columns of the matrix A.
-*
-*  A       (input) REAL array, dimension (LDA,N)
-*          The M-by-N matrix A. Only the upper trapezoid is referenced.
-*
-*  LDA     (input) INTEGER
-*          The leading dimension of the array A.
-*
-*  S       (input) REAL array, dimension (min(M,N))
-*          The singular values of the matrix A.
-*
-*  WORK    (workspace) REAL array, dimension (LWORK)
-*
-*  LWORK   (input) INTEGER
-*          The length of the array WORK. LWORK >= M*N + 4*min(M,N) +
-*          max(M,N).
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -74,7 +131,8 @@
 *
 *     Test that enough workspace is supplied
 *
-      IF( LWORK.LT.M*N+4*MIN( M, N )+MAX( M, N ) ) THEN
+      IF( LWORK.LT.MAX( M*N+4*MIN( M, N )+MAX( M, N ),
+     $                  M*N+2*MIN( M, N )+4*N) ) THEN
          CALL XERBLA( 'SQRT12', 7 )
          RETURN
       END IF
